@@ -35,7 +35,6 @@
 
 open Mm_audio
 open Mm_image
-
 module YUV420 = Image.YUV420
 
 (** Images of videos. *)
@@ -115,7 +114,7 @@ val blank : t -> int -> int -> unit
 val randomize : t -> int -> int -> unit
 
 (** Videos with canvas images. *)
-module Canvas : sig
+module MakeCanvas (_ : Mm_image.Image.CanvasImage) : sig
   module Image : module type of Mm_image.Image.Canvas (Image)
 
   (** An image. *)
@@ -153,7 +152,7 @@ module Canvas : sig
   val map_image : (image -> image) -> t -> int -> unit
 
   (** Render the nth image of the video. *)
-  val render : t -> int -> Mm_image.Image.YUV420.t
+  val render : ?transparent:bool -> t -> int -> Mm_image.Image.YUV420.t
 
   (** Change the contents of the nth image of the video (like [set] but takes an
       image instead of a canvas as argument). *)
@@ -173,6 +172,8 @@ module Canvas : sig
   val iter : (Mm_image.Image.YUV420.t -> unit) -> t -> int -> int -> unit
 end
 
+module Canvas : module type of MakeCanvas (Image)
+
 (* module Ringbuffer_ext : Ringbuffer.R with type elt = frame *)
 
 (* module Ringbuffer : Ringbuffer.R with type elt = frame *)
@@ -190,12 +191,20 @@ module AVI : sig
   (** Writing AVI files. *)
   module Writer : sig
     (** Generate a header for the AVI file. *)
-    val header : ?format:[> `YUV420 ] -> width:int -> height:int -> framerate:int -> ?channels:int -> ?samplerate:int -> ?vendor:string -> unit -> string
+    val header :
+      ?format:[> `YUV420 ] ->
+      width:int ->
+      height:int ->
+      framerate:int ->
+      ?channels:int ->
+      ?samplerate:int ->
+      ?vendor:string ->
+      unit ->
+      string
 
     (** Operations on chunks, which are blocks of (audio / video) data. *)
     module Chunk : sig
       val audio_s16le : Audio.t -> string
-
       val video_yuv420 : YUV420.t -> string
     end
   end
